@@ -13,8 +13,8 @@ public class TagToken extends ReplaceableToken {
 	
 	public String getTokenReplacement() {
 		if(!replaced) {
-			String linkTarget = createHref("", GCubeSocialNetworking.HASHTAG_OID, token);
-			tokenReplacement = createLink(linkTarget, token, null);
+			String linkTarget = ReplaceableToken.createHref("", GCubeSocialNetworking.HASHTAG_OID, token);
+			tokenReplacement = ReplaceableToken.createLink(linkTarget, token, null);
 			replaced = true;
 		}
 		return super.getTokenReplacement();
